@@ -1,6 +1,6 @@
 # Basics must be loaded first
 from .tex_base import *
-from .tex_environment import TexEnvironment, Label
+from .tex_environment import *
 
 # Other features
 from .document import Document, Section, Subsection
@@ -10,3 +10,5 @@ from .floating_environment import FloatingFigure, FloatingTable, FloatingEnviron
 from .plot import Plot, LinePlot, MatrixPlot
 from .template import Template
 from .table import Table, Tabular
+
+from version import __version__
